"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const api_1 = require("@hackmd/api");
const command_1 = require("@oclif/command");
const path = tslib_1.__importStar(require("path"));
const api_2 = require("../api");
const utils_1 = require("../utils");
class Export extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(Export);
        let exportType;
        if (flags.pdf) {
            exportType = api_1.ExportType.PDF;
        }
        else if (flags.html) {
            exportType = api_1.ExportType.HTML;
            // } else if (flags.slides) {
            //   exportType = ExportType.SLIDE
        }
        else {
            exportType = api_1.ExportType.MD;
        }
        try {
            const stream = await api_2.APIClient.exportStream(args.noteId, exportType);
            if (args.output) {
                const outputPath = path.resolve(process.cwd(), args.output);
                await utils_1.pipeToFile(stream, outputPath);
            }
            else {
                await api_2.APIClient.exportStream(args.noteId, exportType);
                stream.pipe(process.stdout);
            }
        }
        catch (e) {
            this.log('Note export failed');
            this.error(e);
        }
    }
}
exports.default = Export;
Export.description = 'Export note to local file or stdout(if the output_file param is omitted)';
Export.examples = [
    '$ hackmd-cli export [--pdf|--md|--html] <note_id> <output_file>',
];
Export.args = [{
        name: 'noteId'
    }, {
        name: 'output'
    }];
Export.flags = {
    help: command_1.flags.help({ char: 'h' }),
    pdf: command_1.flags.boolean(),
    md: command_1.flags.boolean(),
    html: command_1.flags.boolean(),
};
