"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const fs = tslib_1.__importStar(require("fs-extra"));
const path = tslib_1.__importStar(require("path"));
const api_1 = require("../api");
class Import extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(Import);
        if (!args.file) {
            return this.log('No file path specified.');
        }
        const content = fs.readFileSync(path.resolve(process.cwd(), args.file), 'utf-8');
        try {
            const url = await api_1.APIClient.newNote(content, { team: flags.team });
            this.log(`Your note is available at ${url}`);
        }
        catch (err) {
            this.error(err);
        }
    }
}
exports.default = Import;
Import.description = 'Create a note from markdown file';
Import.examples = [
    `$ hackmd-cli import /path/to/markdown/file.md --team=xxx

Your note is available at https://hackmd.io/note-url
`,
];
Import.args = [{
        name: 'file'
    }];
Import.flags = {
    help: command_1.flags.help({ char: 'h' }),
    team: command_1.flags.string({
        char: 't',
        default: '',
        description: 'team to use',
        required: false
    })
};
