"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const inquirer = tslib_1.__importStar(require("inquirer"));
const api_1 = require("../api");
const config_1 = tslib_1.__importDefault(require("../config"));
class Login extends command_1.Command {
    async run() {
        const { flags } = this.parse(Login);
        let id = flags.id || config_1.default.loginID;
        let password = config_1.default.loginPassword || '';
        if (!id) {
            if (flags.ldap) {
                const out = await inquirer.prompt({
                    type: 'input',
                    name: 'username',
                    message: 'Enter your username'
                });
                id = out.username;
                if (!id) {
                    return this.log('No username is given');
                }
            }
            else {
                const out = await inquirer.prompt({
                    type: 'input',
                    name: 'email',
                    message: 'Enter your email'
                });
                id = out.email;
                if (!id) {
                    // TODO: do more email validation
                    return this.log('No email is given');
                }
            }
        }
        if (!password) {
            password = (await inquirer.prompt({
                type: 'password',
                name: 'password',
                message: 'Enter your password'
            })).password;
        }
        try {
            if (flags.ldap) {
                await api_1.APIClient.loginLdap(id, password);
            }
            else {
                await api_1.APIClient.login(id, password);
            }
            const login = await api_1.APIClient.isLogin();
            if (login) {
                return this.log('Login successfully');
            }
            else {
                this.log('Login failed, please ensure your credentials are set');
            }
        }
        catch (err) {
            this.error(err);
        }
    }
}
exports.default = Login;
Login.description = 'Login to HackMD/CodiMD server from CLI';
Login.examples = [
    `$ hackmd-cli login

Enter your email: hello@hackmd.io
Enter your password: *******

Login as HMD successfully!
`,
];
Login.flags = {
    help: command_1.flags.help({ char: 'h' }),
    id: command_1.flags.string({ char: 'u', description: 'Login email/username' }),
    ldap: command_1.flags.boolean()
};
